@@ -12,13 +12,14 @@ class Trigger(object):
     box_class = None
     client = None
 
-    def __init__(self, box_class, host, port, ensure=True):
+    def __init__(self, box_class, host, port, ensure=False):
         self.box_class = box_class
         self.client = Client((host, port), ensure)
 
     def write_to_worker(self, data, params=None):
         """
         透传到worker进行处理
+        :param data 数据
         :param params 指定task的参数, dict类型
         """
 
